Function dark_light::detect
source · [−]pub fn detect() -> ModeExpand description
Detect if light mode or dark mode is enabled. If the mode can’t be detected, fall back to Mode::Light.
pub fn detect() -> ModeDetect if light mode or dark mode is enabled. If the mode can’t be detected, fall back to Mode::Light.